| extract_times | R Documentation |
Helper function to consistently obtain and validate the time points associated with a probability matrix or vector.
extract_times(x, times = NULL)
x |
( |
times |
( |
A validated numeric vector of time points.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.